등록특허 10-0680003

분자 내 이졸 N-알릴화반응에 의한 페레리 디리의 최종 편리화 반응에 기초한 3-2-[4-(6-플로로벤조(D))아이소우사졸 -3-일)-페레리딘-1-일]-에탄-2-메탄-6,7,8,9-테트라하이드로-4H-페리도-(1,2-a)페리미딘-4-은(I)의 제조를 위한 방법을 개시하고 있다(도식 2).

중간체 VIII의 제조에 사용되는 충발 불침름 중에 하나는 상염적으로 입수할 수 없는 4-테트라하이드로페닐카보닐클로라 이트(IX)이다. 계다가, IX로부터 VIII을 제조하는 것은 다섯 단계로 이루어진다(스페이싱 제2074966호).

본 발명은 3-2-[4-(6-플로로벤조(D)아이소우사졸-3-일)-페레리딘-1-일]-에탄-2-메탄-6,7,8,9-테트라하이드로4H-페리도-(1,2-a)페리미딘-4-은(I)의 제조를 위한 대체적 방법을 제공하며, 그 과정이 도식 3에 도해되어있다.

- 6 -